/**
 * Highlights an element containing source code.  Upon completion of this function,
 * the element will have been placed in the "sh_sourcecode" class.
 * @param {Language} language - a language definition object
 * @param {Element} element - a DOM <pre> element containing the source code to be highlighted
 */
export function highlightElement(language: Language, element: Element): void;
/**
 * Highlights all elements containing source code on the current page. Elements
 * containing source code must be "pre" elements with a "class" attribute of
 * "sh_LANGUAGE", where LANGUAGE is a valid language identifier; e.g., "sh_java"
 * identifies the element as containing "java" language source code.
 * @param {Object.<string, Language>} languages - List of imported language objects
 */
export function highlightDocument(languages: {
    [x: string]: Language;
}): void;
/**
 * A language definition object
 */
export type Language = [RegExp, string, number, number?][][];
/**
 * A pattern with an expression to match, a css class,
 * a keyword position (?), and an state type (?)
 */
export type LanguagePattern = [RegExp, string, number, number?];
/**
 * A tag object with its position
 */
export type Tag = {
    pos: number;
    tagName?: string;
    style?: string;
    href?: string;
};
